@@ -4,21 +4,22 @@ def wtforms_translation_string_factory(domain):
     class _WTFormsLazyTranslationString:
         '''This class used for deferring message translation until rendering stage.'''
 
-        def __init__(self, msg):
+        def __init__(self, msg, mapping=None):
             from . import LazyTranslationString
             self.msg = msg
+            self.mapping = mapping
             self.lts = LazyTranslationString(domain)
 
         def __str__(self):
-            return self.lts.translate(self.msg)
+            return self.lts.translate(self.msg, mapping=self.mapping)
     
     return _WTFormsLazyTranslationString
 
 
 def wtforms_translate_i18n_now(form):
     '''
-    When using wtforms_translation_string_factory with json renderer,
-
+    When using wtforms_translation_string_factory with json renderer, we need translate strings
+    first in order to render the result to the front. This function helps us to achieve this purpose.
     '''
     from wtforms import FormField, FieldList
     for key, field in form._fields.items():
